@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0403';
+our $VERSION = '0.0404';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -72,7 +72,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0403
+version 0.0404
 
 =head1 SYNOPSIS
 
@@ -84,7 +84,7 @@ version 0.0403
 
   say $t->soundfont;
 
-  for my $i (1 .. 3) {
+  for (1 .. $t->bars) {
     $t->strike('ta', $t->eighth);
     $t->strike('ta', $t->eighth);
     $t->strike('tun');
@@ -143,7 +143,7 @@ this to add to the C<84>th MIDInum entry score:
 
 To play patches simultaneously, that would be:
 
-  $tabla->note($tabla->eighth, 79, 84);
+  $tabla->note($tabla->eighth, 84, 79);
 
 =head1 ATTRIBUTES
 
@@ -153,12 +153,14 @@ To play patches simultaneously, that would be:
 
 The file location, where the tabla soundfont resides.
 
-Default: F<dist_dir()/Tabla.sf2>
+Default: C<dist_dir()/Tabla.sf2>
 
 =head2 patches
 
   $patches = $tabla->patches;
 
+Each bol can be 1 or more patch numbers.
+
 Default bol patches:
 
   dhun: 67 80
@@ -208,7 +210,7 @@ L<Moo>
 
 L<File::ShareDir>
 
-L<https://gleitz.github.io/midi-js-soundfonts/Tabla/Tabla.sf2>
+L<https://gleitz.github.io/midi-js-soundfonts/Tabla/Tabla.sf2> (4.1MB)
 
 L<https://www.wikihow.com/Play-Tabla>
 
@@ -219,7 +221,7 @@ L<https://kksongs.org/tabla/chapter03.html>
 
 =head1 AUTHOR
 
-Gene Boggs <gene@cpan.org>
+Gene Boggs <gene.boggs@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
